@@ -9,6 +9,7 @@ Basic usage:
 """
 import re
 import abc
+import sys
 import idna
 import socket
 import asyncio
@@ -18,6 +19,10 @@ import aiodns
 
 from .providers import Provider, BASE_PROVIDERS, BASE_DOMAIN_PROVIDERS
 
+if sys.platform == 'win32' and sys.version_info >= (3, 8):
+    # fixes https://github.com/dmippolitov/pydnsbl/issues/12
+    asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
+
 class DNSBLResult:
     """
     DNSBL Result class to keep all info about ip request results.
